from django.db import models
from ProjectInfoDisplay.models import Project
from File.models import File

class Decision(models.Model):
    STATUS_CHPICES = (
        ("DONE","已完成"),
        ("DOING","正在办理"),
        ("CANNOT","无法办理"),
        ("NEEDNOT","不用办理"),
        ("WILLDO","尚未办理"),
    )
    decision_id = models.AutoField(verbose_name="决策条目主键",primary_key=True)
    project = models.ForeignKey(
        Project,
        verbose_name="对应的工程项目",
        on_delete=models.CASCADE
    )
    title = models.CharField(verbose_name="决策条目名称",max_length=128)
    estimate = models.DecimalField(verbose_name="预计花费",max_digits=12, decimal_places=2, null=True, blank=True,default=0
                               , help_text="限制其为小数（decimal），10.2（数字代表最大位数，eg.小数点前最大为7位）")
    actual = models.DecimalField(verbose_name="实际花费", max_digits=12, decimal_places=2, null=True, blank=True
                                   , help_text="限制其为小数（decimal），10.2（数字代表最大位数，eg.小数点前最大为7位）")
    status = models.CharField(verbose_name="状态",choices=STATUS_CHPICES,
                              max_length=8,default="WILLDO")

    class Meta:
        verbose_name = "项目决策阶段条目"
        verbose_name_plural=verbose_name

    def __str__(self):
        return self.title

class DecisionMatter(models.Model):
    matter_id = models.AutoField(verbose_name="办理事项主键",primary_key=True)
    decision = models.ForeignKey(
        Decision,
        verbose_name="对应的决策条目",
        on_delete=models.CASCADE
    )
    matter = models.CharField(verbose_name="办理事项",max_length=256)
    number = models.CharField(verbose_name="份数",max_length=256,null=True,blank=True,help_text="可空可不填")
    department = models.CharField(verbose_name="办理部门",max_length=256,null=True,blank=True,help_text="可空可不填")
    status = models.CharField(verbose_name="状态",max_length=256,null=True,blank=True,help_text="可空可不填")
    telephone = models.CharField(verbose_name="联系方式",max_length=256,null=True,blank=True,help_text="可空可不填")
    paid_status = models.CharField(verbose_name="是否缴费",max_length=256,null=True,blank=True,help_text="可空可不填")
    deal_time = models.CharField(verbose_name="办理时限",max_length=256,null=True,blank=True,help_text="可空可不填")
    note = models.CharField(verbose_name="备注",max_length=256,null=True,blank=True,help_text="可空可不填")
    file = models.ManyToManyField(
        File,
        verbose_name="所需文件",
        blank=True
        )

    class Meta:
        verbose_name = "项目决策阶段对应办理事项"
        verbose_name_plural = verbose_name

    def __str__(self):
        return self.matter
