from rest_framework import generics
from . import models
from . import serializers
from rest_framework.permissions import IsAuthenticated
class DecisionAPIView(generics.ListAPIView):
    queryset = models.Decision.objects.all().order_by('decision_id')
    serializer_class = serializers.DecisionSerializer
    permissions = (IsAuthenticated,)

    def get_queryset(self):
        return self.queryset.filter(project = self.request.GET.get('project_id'))

class DecisionDetailAPIView(generics.RetrieveUpdateAPIView):
    queryset = models.Decision.objects.all()
    serializer_class = serializers.DecisionSerializer
    permission_classes = (IsAuthenticated,)
    lookup_field = 'decision_id'

class DecisionMatterAPIView(generics.ListCreateAPIView):
    queryset = models.DecisionMatter.objects.all().order_by('matter_id')
    serializer_class = serializers.DecisionMatterSerializer
    permission_classes = (IsAuthenticated,)

    def get_queryset(self):
        return self.queryset.filter(decision = self.request.GET.get('decision_id'))
    def perform_create(self, serializer):
        serializer.save(decision=models.Decision.objects.get(
            decision_id=self.request.GET.get('decision_id')))

class DecisionMatterDetailAPIView(generics.RetrieveUpdateDestroyAPIView):
    queryset = models.DecisionMatter.objects.all()
    serializer_class = serializers.DecisionMatterSerializer
    permission_classes = (IsAuthenticated,)
    lookup_field = 'matter_id'
