import { BasicLayout, PageView, UserLayout } from '@/components/layouts'

export const asyncRouterMap = [
  {
    path: '/',
    component: BasicLayout,
    meta: { title: '首页' },
    redirect: '/project',
    children: [
      {
        path: '/dashboard',
        name: 'dashboard',
        component: () => import(/* webpackChunkName: "dashboard" */ '../views/dashboard/Dashboard'),
        meta: { title: '仪表盘测试', icon: 'dashboard', permission: ['dashboard'] }
      },
      {
        path: '/project',
        name: 'project',
        component: () => import(/* webpackChunkName: "project" */ '../views/project/Project'),
        meta: { title: '项目列表', icon: 'table', permission: ['project'] }
      },
      {
        path: '/project/create',
        name: 'projectCreate',
        component: () => import(/* webpackChunkName: "project" */ '../views/project/ProjectDetail'),
        hidden: true,
        meta: { title: '新建项目', permission: ['project'] }
      },
      {
        path: '/project/edit',
        name: 'projectEdit',
        component: () => import(/* webpackChunkName: "project" */ '../views/project/ProjectDetail'),
        hidden: true,
        meta: { title: '新建项目', permission: ['project'] }
      },
      {
        path: '/detail',
        component: PageView,
        meta: { title: '项目详情', icon: 'profile', permission: ['detail', 'project_selected'] },
        children: [
          {
            path: '',
            name: 'detail',
            component: () => import(/* webpackChunkName: "detail" */ '../views/detail/Detail'),
            meta: { title: '项目详情' }
          },
          {
            path: 'contact',
            name: 'contact',
            component: () => import(/* webpackChunkName: "detail" */ '../views/detail/Contact'),
            meta: { title: '通讯录' }
          }
        ]
      },
      {
        path: '/decision',
        name: 'decision',
        component: () => import(/* webpackChunkName: "decision" */ '../views/decision/Decision'),
        meta: { title: '项目决策', icon: 'audit', permission: ['decision', 'project_selected'] }
      },
      {
        path: '/decision/:id',
        name: 'decisionDetail',
        component: () => import(/* webpackChunkName: "decision" */ '../views/decision/DecisionDetail'),
        props: true,
        hidden: true,
        meta: { title: '决策详情', permission: ['decision', 'project_selected'] }
      },
      {
        path: '/implement',
        name: 'implement',
        component: PageView,
        meta: { title: '项目实施', icon: 'tool', permission: ['implement', 'project_selected'] },
        children: [
          {
            path: 'application',
            name: 'implementApplication',
            component: () => import(/* webpackChunkName: "Implement" */ '../views/implement/application/Application'),
            meta: { title: '报批报建' }
          },
          {
            path: 'application/Edit',
            name: 'implementApplicationEdit',
            hidden: true,
            component: () => import(/* webpackChunkName: "Implement" */ '../views/implement/application/ApplicationEdit'),
            meta: { title: '报批报建修改' }
          },
          {
            path: 'application/:id',
            name: 'implementApplicationDetail',
            component: () => import(/* webpackChunkName: "Implement" */ '../views/implement/application/ApplicationDetail'),
            props: true,
            hidden: true,
            meta: { title: '报批报建详情' }
          },
          {
            path: 'bid',
            name: 'implementBid',
            component: () => import(/* webpackChunkName: "Implement" */ '../views/implement/bid/Bid'),
            meta: { title: '招标采购' }
          },
          {
            path: 'design',
            name: 'implementDesign',
            component: () => import(/* webpackChunkName: "Implement" */ '../views/implement/design/Design'),
            meta: { title: '设计管理' }
          },
          {
            path: 'design/:id',
            name: 'implementDesignDetail',
            props: true,
            hidden: true,
            component: () => import(/* webpackChunkName: "Implement" */ '../views/implement/design/DesignDetail'),
            meta: { title: '设计管理详情' }
          },
          {
            path: '4',
            name: '4',
            component: () => import('@/views/implement/Implement'),
            meta: { title: '投资管理' }
          },
          {
            path: '5',
            name: '5',
            component: () => import('@/views/implement/Implement'),
            meta: { title: '进度管理' }
          },
          {
            path: '6',
            name: '6',
            component: () => import('@/views/implement/Implement'),
            meta: { title: '质量管理' }
          },
          {
            path: '7',
            name: '7',
            component: () => import('@/views/implement/Implement'),
            meta: { title: '安全管理' }
          },
          {
            path: '8',
            name: '8',
            component: () => import('@/views/implement/Implement'),
            meta: { title: '合同管理' }
          },
          {
            path: '9',
            name: '9',
            component: () => import('@/views/implement/Implement'),
            meta: { title: '应急管理' }
          },
          {
            path: '10',
            name: '10',
            component: () => import('@/views/implement/Implement'),
            meta: { title: '来往函件' }
          },
          {
            path: '11',
            name: '11',
            component: () => import('@/views/implement/Implement'),
            meta: { title: '周月报表' }
          }
        ]
      },
      {
        path: '/completion',
        name: 'completion',
        component: PageView,
        meta: { title: '项目竣工', icon: 'bank', permission: ['completion', 'project_selected'] }
      },
      {
        path: '/video',
        name: 'video',
        component: PageView,
        meta: { title: '项目视频', icon: 'video-camera', permission: ['video', 'project_selected'] }
      },
      {
        path: '/account',
        name: 'account',
        component: PageView,
        meta: { title: '用户管理', icon: 'user', permission: ['account'] }
      },
      {
        path: '/setting',
        component: PageView,
        meta: { title: '设置', icon: 'setting', permission: ['setting'] },
        children: [
          {
            path: '',
            name: 'setting',
            component: () => import(/* webpackChunkName: "setting" */ '../views/setting/Setting'),
            meta: { title: '通用设置', permission: ['setting'] }
          },
          {
            path: 'user',
            name: 'settingUser',
            component: () => import(/* webpackChunkName: "setting" */ '../views/setting/User'),
            meta: { title: '用户设置', permission: ['setting'] }
          },
          {
            path: 'project',
            name: 'settingProject',
            component: () => import(/* webpackChunkName: "setting" */ '../views/setting/Project'),
            meta: { title: '项目设置', permission: ['setting'] }
          }
        ]
      },
      {
        path: '/help',
        name: 'help',
        component: PageView,
        meta: { title: '帮助', icon: 'question-circle', permission: ['help'] }
      }
    ]
  },
  {
    path: '*', redirect: '/404', hidden: true
  }
]

/**
 * 基础路由
 * @type { *[] }
 */
export const constantRouterMap = [
  {
    path: '/user',
    component: UserLayout,
    redirect: '/user/login',
    hidden: true,
    children: [
      {
        path: 'login',
        name: 'login',
        component: () => import(/* webpackChunkName: "user" */ '@/views/user/Login')
      }
    ]
  },
  {
    path: '/404',
    component: () => import(/* webpackChunkName: "fail" */ '@/views/exception/404')
  }
]
