from django.db import models
from ProjectInfoDisplay.models import Project
from File.models import File

class Application(models.Model):
    STATUS_CHPICES = (
        ("DONE","已完成"),
        ("DOING","正在办理"),
        ("CANNOT","无法办理"),
        ("NEEDNOT","不用办理"),
        ("WILLDO","尚未办理"),
    )
    application_id = models.AutoField(verbose_name="报批报建条目主键",primary_key=True)
    project = models.ForeignKey(
        Project,
        verbose_name="对应的工程项目",
        on_delete=models.CASCADE
    )
    title = models.CharField(verbose_name="报批报建条目名称",max_length=128)
    estimate = models.DecimalField(verbose_name="预计花费",max_digits=12, decimal_places=2, null=True, blank=True,default=0
                               , help_text="限制其为小数（decimal），10.2（数字代表最大位数，eg.小数点前最大为7位）")
    actual = models.DecimalField(verbose_name="实际花费", max_digits=12, decimal_places=2, null=True, blank=True
                                   , help_text="限制其为小数（decimal），10.2（数字代表最大位数，eg.小数点前最大为7位）")
    status = models.CharField(verbose_name="状态",choices=STATUS_CHPICES,
                              max_length=8,default="WILLDO")

    class Meta:
        verbose_name = "报批报建条目"
        verbose_name_plural=verbose_name

    def __str__(self):
        return self.title

class ApplicationMatter(models.Model):
    matter_id = models.AutoField(verbose_name="办理事项主键",primary_key=True)
    application = models.ForeignKey(
        Application,
        verbose_name="对应的决策条目",
        on_delete=models.CASCADE
    )
    matter = models.CharField(verbose_name="办理事项",max_length=256)
    number = models.CharField(verbose_name="份数",max_length=256,null=True,blank=True,help_text="可空可不填")
    department = models.CharField(verbose_name="办理部门",max_length=256,null=True,blank=True,help_text="可空可不填")
    status = models.CharField(verbose_name="状态",max_length=256,null=True,blank=True,help_text="可空可不填")
    telephone = models.CharField(verbose_name="联系方式",max_length=256,null=True,blank=True,help_text="可空可不填")
    paid_status = models.CharField(verbose_name="是否缴费",max_length=256,null=True,blank=True,help_text="可空可不填")
    deal_time = models.CharField(verbose_name="办理时限",max_length=256,null=True,blank=True,help_text="可空可不填")
    note = models.CharField(verbose_name="备注",max_length=256,null=True,blank=True,help_text="可空可不填")
    file = models.ManyToManyField(
        File,
        verbose_name="所需文件",
        blank=True
        )

    class Meta:
        verbose_name = "报批报建对应办理事项"
        verbose_name_plural = verbose_name

    def __str__(self):
        return self.matter

class BidItem(models.Model):
    STATUS_CHOICES = (
        ("DONE", "已完成"),
        ("DOING", "进行中"),
        ("WILL", "未开始"),
    )
    bid_id = models.AutoField(verbose_name="招标采购条目主键",primary_key=True)
    project = models.ForeignKey(
        Project,
        verbose_name="对应的工程项目",
        on_delete=models.CASCADE
    )
    name = models.CharField(verbose_name="招标采购条目名称",max_length=64)
    status = models.CharField(verbose_name="状态", choices=STATUS_CHOICES,
                              max_length=8, default="WILL",help_text="可空可不填，默认为WILL（未开始）")
    contract_time = models.CharField(verbose_name="代理合同时间",max_length=32,blank=True,null=True,help_text="可空可不填")
    estimated_time = models.CharField(verbose_name="预计时间",max_length=32,blank=True,null=True,help_text="可空可不填")
    announce_time = models.CharField(verbose_name="公告时间",max_length=32,blank=True,null=True,help_text="可空可不填")
    control_price = models.DecimalField(verbose_name="招标控制价",max_digits=10,decimal_places=2,blank=True,null=True,
                                        help_text="限制其为小数（decimal），8.2;可空可不填")
    bid_time = models.CharField(verbose_name="招标时间",max_length=32,blank=True,null=True,help_text="可空可不填")
    bid_company = models.CharField(verbose_name="中标单位",max_length=32,blank=True,null=True,help_text="可空可不填")
    linkman = models.CharField(verbose_name="联系人",max_length=256,blank=True,null=True,help_text="可空可不填")
    phone = models.CharField(verbose_name="电话",max_length=32,blank=True,null=True,help_text="可空可不填")
    approach_time = models.CharField(verbose_name="进场时间",max_length=32,blank=True,null=True,help_text="可空可不填")
    agency_fee = models.DecimalField(verbose_name="代理费",max_digits=10,decimal_places=2,blank=True,null=True,
                                        help_text="限制其为小数（decimal），8.2;可空可不填")
    bid_price = models.DecimalField(verbose_name="中标金额",max_digits=10,decimal_places=2,blank=True,null=True,
                                        help_text="限制其为小数（decimal），8.2;可空可不填")

    class Meta:
        verbose_name = "招标采购条目"
        ordering = ['bid_id']
        verbose_name_plural = verbose_name

    def __str__(self):
        return self.name

    def get_save_rate(self):
        if(self.control_price and self.bid_price):
            return ((self.control_price - self.bid_price) / self.control_price)*100
        else:
            return 0

class DesignItem(models.Model):
    design_item_id = models.AutoField(primary_key=True,verbose_name="设计条目主键")
    project = models.ForeignKey(
        Project,
        verbose_name="对应的工程项目",
        on_delete=models.CASCADE
    )
    name = models.CharField(verbose_name="设计条目名称",max_length=16)
    files = models.ManyToManyField(
        File,
        verbose_name="对应文件",
        blank=True
    )

    class Meta:
        verbose_name = "设计管理条目"
        ordering = ['design_item_id']
        verbose_name_plural = verbose_name

    def __str__(self):
        return self.name


class DesignItemDoing(models.Model):
    project = models.OneToOneField(
        Project,
        verbose_name="对应工程",
        on_delete=models.CASCADE,
    )
    design_item = models.OneToOneField(
        DesignItem,
        verbose_name="正在进行的设计条目",
        on_delete=models.CASCADE
    )

    class Meta:
        verbose_name = "正在进行的设计条目"
        ordering = ['id']
        verbose_name_plural = verbose_name

class DesignCompany(models.Model):
    company_id = models.AutoField(verbose_name="设计公司主键",primary_key=True)
    project = models.ForeignKey(
        Project,
        verbose_name="对应工程",
        on_delete=models.CASCADE,
    )
    name = models.CharField(verbose_name="设计单位名称",max_length=128)
    type = models.CharField(verbose_name="类别",max_length=128,null=True,blank=True)
    project_name = models.CharField(verbose_name="项目名称",max_length=128,null=True,blank=True)
    contract_price = models.DecimalField(verbose_name="合同额",max_digits=10
                                         ,decimal_places=2,help_text="8.2",null=True,blank=True)
    settled_price = models.DecimalField(verbose_name="结算额",max_digits=10
                                         ,decimal_places=2,help_text="8.2",null=True,blank=True)
    paid_total = models.DecimalField(verbose_name="结算额",max_digits=10
                                         ,decimal_places=2,help_text="8.2",null=True,blank=True)
    should_pay = models.DecimalField(verbose_name="结算额",max_digits=10
                                         ,decimal_places=2,help_text="8.2",null=True,blank=True)
    actual_pay = models.DecimalField(verbose_name="结算额",max_digits=10
                                         ,decimal_places=2,help_text="8.2",null=True,blank=True)

    class Meta:
        verbose_name = "设计公司"
        ordering = ['company_id']
        verbose_name_plural = verbose_name

    def __str__(self):
        return self.name