from rest_framework import generics
from . import serializers
from rest_framework.permissions import IsAuthenticated
from ProjectInfoDisplay.models import Project
from rest_framework.views import APIView
from rest_framework.response import Response
from . import models
from decimal import Decimal
from File.models import File
from rest_framework import exceptions


class ApplicationAPIView(generics.ListCreateAPIView):
    queryset = models.Application.objects.all().order_by('application_id')
    serializer_class = serializers.ApplicationSerializer
    permissions = (IsAuthenticated,)

    def get_queryset(self):
        return self.queryset.filter(project=self.request.GET.get('project_id'))

    def perform_create(self, serializer):
        serializer.save(project=Project.objects.get(id=self.request.GET.get('project_id')))


class ApplicationDetailAPIView(generics.RetrieveUpdateDestroyAPIView):
    queryset = models.Application.objects.all()
    serializer_class = serializers.ApplicationSerializer
    permission_classes = (IsAuthenticated,)
    lookup_field = 'application_id'


class ApplicationMatterAPIView(generics.ListCreateAPIView):
    queryset = models.ApplicationMatter.objects.all()
    serializer_class = serializers.ApplicationMatterSerializer
    permission_classes = (IsAuthenticated,)

    def get_queryset(self):
        return self.queryset.filter(application=self.request.GET.get('application_id'))

    def perform_create(self, serializer):
        serializer.save(application=models.Application.objects.get(
            application_id=self.request.GET.get('application_id')))


class ApplicationMatterDetailAPIView(generics.RetrieveUpdateDestroyAPIView):
    queryset = models.ApplicationMatter.objects.all()
    serializer_class = serializers.ApplicationMatterSerializer
    permission_classes = (IsAuthenticated,)
    lookup_field = 'matter_id'


class BidAPIView(generics.ListCreateAPIView):
    queryset = models.BidItem.objects.all()
    serializer_class = serializers.BidSerializer
    permission_classes = (IsAuthenticated,)

    def get_queryset(self):
        return self.queryset.filter(project=self.request.GET.get('project_id'))

    def perform_create(self, serializer):
        serializer.save(project=Project.objects.get(id=self.request.GET.get('project_id')))


class BidDetailAPIView(generics.RetrieveUpdateDestroyAPIView):
    queryset = models.BidItem.objects.all()
    serializer_class = serializers.BidSerializer
    permission_classes = (IsAuthenticated,)
    lookup_field = 'bid_id'


class BidStatusAPIView(APIView):
    def get(self, request):
        status = models.BidItem.STATUS_CHOICES
        list = []
        for item in status:
            list.append({
                'value': item[0],
                'label': item[1]
            })
        return Response(list)


class BidSumAPIView(APIView):
    def get(self, request):
        bid = models.BidItem.objects.filter(project_id=
                                            request.GET.get("project_id"))
        save_rate_all = 0.00
        bid_price = 0.00
        control_price = 0.00
        count = 0.00
        for b in bid:
            if (b.bid_price and b.control_price):
                save_rate_all = save_rate_all + float(b.get_save_rate())
                bid_price = bid_price + float(b.bid_price)
                control_price = control_price + float(b.control_price)
                count = count + 1.00
            else:
                continue
        if (save_rate_all != 0.00):
            save_rate = save_rate_all / count
        else:
            save_rate = 0
        return Response({
            "save_rate": Decimal(save_rate).quantize(Decimal('0.00')),
            "control_price": Decimal(control_price).quantize(Decimal('0.00')),
            "bid_price": Decimal(bid_price).quantize(Decimal('0.00'))
        })


class DesignItemAPIView(generics.ListAPIView):
    queryset = models.DesignItem.objects.all()
    serializer_class = serializers.DesignItemSerializer
    permission_classes = (IsAuthenticated,)

    def get_queryset(self):
        return self.queryset.filter(project=self.request.GET.get('project_id'))


class DesignItemDetailAPIView(generics.RetrieveAPIView):
    queryset = models.DesignItem.objects.all()
    serializer_class = serializers.DesignItemSerializer
    permission_classes = (IsAuthenticated,)
    lookup_field = 'design_item_id'


class DesignItemDoingAPIView(generics.ListAPIView):
    queryset = models.DesignItemDoing.objects.all()
    serializer_class = serializers.DesignItemDoingSerializer
    permission_classes = (IsAuthenticated,)

    def get_queryset(self):
        return self.queryset.filter(project=self.request.GET.get('project_id'))


class DesignItemDoingDetailAPIView(generics.UpdateAPIView):
    queryset = models.DesignItemDoing.objects.all()
    serializer_class = serializers.DesignItemDoingSerializer
    permission_classes = (IsAuthenticated,)
    lookup_field = 'id'


class DesignItemFileAPIView(APIView):
    def post(self, request, design_item_id):
        uuid = request.data.get('uuid')
        if uuid:
            file = File.objects.get(uuid=uuid)
            design_item = models.DesignItem.objects.get(design_item_id=design_item_id)
            design_item.files.add(file)
            data = models.DesignItem.objects.get(
                design_item_id=design_item_id)
            serializer = serializers.DesignItemSerializer(data)
            return Response(serializer.data)
        raise exceptions.APIException("未传uuid！")


class DesignItemFileDetailAPIView(APIView):
    def delete(self, request, id):
        file = File.objects.get(id=id)
        file.delete()
        return Response("删除成功")

class DesignCompanyAPIView(generics.ListCreateAPIView):
    queryset = models.DesignCompany.objects.all()
    serializer_class = serializers.DesignCompanySerializer
    permission_classes = (IsAuthenticated,)

    def get_queryset(self):
        return self.queryset.filter(project=self.request.GET.get('project_id'))

    def perform_create(self, serializer):
        serializer.save(project=Project.objects.get(id=self.request.GET.get('project_id')))


class DesignCompanyDetailAPIView(generics.RetrieveUpdateDestroyAPIView):
    queryset = models.DesignCompany.objects.all()
    serializer_class = serializers.DesignCompanySerializer
    permission_classes = (IsAuthenticated,)
    lookup_field = 'company_id'