from django.db import models
from User.models import User
from File.models import File
class ProjectScale(models.Model):
    value = models.AutoField(verbose_name="编号", primary_key=True)
    label = models.CharField(verbose_name="规模大小", max_length=32, unique=True)
    description = models.CharField(verbose_name="具体描述", max_length=64, null=True, blank=True)

    class Meta:
        verbose_name = '项目工程规模'
        ordering = ['value']
        verbose_name_plural = verbose_name

    def __str__(self):
        return self.label


class ProjectProperty(models.Model):
    value = models.AutoField(verbose_name="编号", primary_key=True)
    label = models.CharField(verbose_name="工程性质", max_length=32, unique=True)
    description = models.CharField(verbose_name="具体描述", max_length=64, null=True, blank=True)

    class Meta:
        verbose_name = '项目工程性质'
        ordering = ['value']
        verbose_name_plural = verbose_name

    def __str__(self):
        return self.label


class ProjectPurpose(models.Model):
    value = models.AutoField(verbose_name="编号", primary_key=True)
    label = models.CharField(verbose_name="项目用途", max_length=32, unique=True)
    description = models.CharField(verbose_name="具体描述", max_length=64, null=True, blank=True)

    class Meta:
        verbose_name = '项目工程用途'
        ordering = ['value']
        verbose_name_plural = verbose_name

    def __str__(self):
        return self.label


class FundSources(models.Model):
    value = models.AutoField(verbose_name="编号", primary_key=True)
    label = models.CharField(verbose_name="资金来源", max_length=16, unique=True)
    description = models.CharField(verbose_name="具体描述", max_length=64, null=True, blank=True)

    class Meta:
        verbose_name = '项目工程资金来源'
        ordering = ['value']
        verbose_name_plural = verbose_name

    def __str__(self):
        return self.label


class Style(models.Model):
    value = models.AutoField(verbose_name="编号", primary_key=True)
    label = models.CharField(verbose_name="结构形式", max_length=32, unique=True)
    description = models.CharField(verbose_name="具体描述", max_length=64, null=True, blank=True)

    class Meta:
        verbose_name = '项目工程结构形式'
        ordering = ['value']
        verbose_name_plural = verbose_name

    def __str__(self):
        return self.label


class Project(models.Model):
    id = models.CharField(verbose_name="项目编号", primary_key=True, max_length=11)
    user = models.ManyToManyField(
        User,
        verbose_name='可操作用户',
    )
    name = models.CharField(verbose_name="项目名称", max_length=256)
    place = models.CharField(verbose_name="建筑地点", max_length=128)
    starting_date = models.DateField(verbose_name="开工日期", help_text="两种格式：2018-01-02 | 2019/01/03")
    finishing_date = models.DateField(verbose_name="预计竣工日期", help_text="两种格式：2018-01-02 | 2019/01/03")
    investment = models.DecimalField(verbose_name='投资额', max_digits=16, decimal_places=6, null=True, blank=True
                                     , help_text="限制其为小数（decimal），10.6（数字代表最大位数，eg.小数点前最大为10位）")
    introduction = models.TextField(verbose_name="项目简介", max_length=2000, null=True, blank=True
                                    , help_text="最大输入为2000（1000字）")
    scale = models.ForeignKey(
        ProjectScale,
        to_field='value',
        verbose_name="工程概况规模",
        on_delete=models.CASCADE)
    property = models.ManyToManyField(
        ProjectProperty,
        verbose_name="性质", )
    purpose = models.ManyToManyField(
        ProjectPurpose,
        verbose_name="用途", )
    fund_sources = models.ManyToManyField(
        FundSources,
        verbose_name="资金来源", )
    cost = models.DecimalField(verbose_name='工程总造价', max_digits=16, decimal_places=6, null=True, blank=True
                               , help_text="限制其为小数（decimal），10.6（数字代表最大位数，eg.小数点前最大为10位）")
    condition = models.TextField(verbose_name="施工条件", max_length=2000, null=True, blank=True
                                 , help_text="最大输入为2000（1000字）")
    area = models.DecimalField(verbose_name="总建筑面积(平方米)", max_digits=10, decimal_places=3, null=True, blank=True
                               , help_text="限制其为小数（decimal），7.3（数字代表最大位数，eg.小数点前最大为7位）")
    style = models.ManyToManyField(
        Style,
        verbose_name="结构形式", )
    images = models.ForeignKey(
        File,
        verbose_name="项目照片",
        on_delete=models.CASCADE,
        null=True, blank=True)

    class Meta:
        verbose_name = '项目信息'
        ordering = ['id']
        verbose_name_plural = verbose_name

    def __str__(self):
        return self.name


class CompanyType(models.Model):
    value = models.AutoField(verbose_name="编号", primary_key=True)
    label = models.CharField(verbose_name="单位类型", max_length=32, unique=True)
    # 后期需要加入label的查询，在后台的维护界面
    description = models.CharField(verbose_name="具体描述", max_length=64, null=True, blank=True)

    class Meta:
        verbose_name = '通讯录单位类型'
        ordering = ['value']
        verbose_name_plural = verbose_name

    def __str__(self):
        return self.label


class AddressList(models.Model):
    company = models.CharField(verbose_name="单位名称", max_length=64)
    project = models.ForeignKey(
        Project,
        verbose_name="对应工程",
        on_delete=models.CASCADE
    )
    company_type = models.ForeignKey(CompanyType,
                                     to_field='value',
                                     verbose_name="单位类型",
                                     on_delete=models.CASCADE,
                                     help_text="可以为空")
    name = models.CharField(verbose_name="单位负责人名字", max_length=16)
    job = models.CharField(verbose_name="负责人职位", max_length=16, null=True, blank=True,
                           help_text="职位，可以为空")
    email = models.EmailField(verbose_name="负责人邮箱", null=True, blank=True,
                              help_text="可以为空   邮箱正则化验证")
    telephone = models.CharField(verbose_name="负责人电话号", max_length=11,
                                 help_text="电话，11位")
    note = models.CharField(verbose_name="备注", max_length=256, null=True, blank=True,
                            help_text="可以为空")

    class Meta:
        verbose_name = '通讯录'
        ordering = ['id']
        verbose_name_plural = verbose_name

    def __str__(self):
        return self.company
