from drf_writable_nested import WritableNestedModelSerializer
from rest_framework import serializers

from File.serializers import FileSerializers
from ProjectInfoDisplay.models import \
    Project, Style, ProjectScale, FundSources, ProjectPurpose, ProjectProperty, CompanyType, AddressList


class ProjectScaleSerializer(serializers.ModelSerializer):
    class Meta:
        model = ProjectScale
        fields = '__all__'
        read_only_fields = ('description', 'label')


class StyleSerializer(serializers.ModelSerializer):
    class Meta:
        model = Style
        fields = '__all__'
        read_only_fields = ('description', 'label')


class FundSourcesSerializer(serializers.ModelSerializer):
    class Meta:
        model = FundSources
        fields = '__all__'
        read_only_fields = ('description', 'label')


class ProjectPurposeSerializer(serializers.ModelSerializer):
    class Meta:
        model = ProjectPurpose
        fields = '__all__'
        read_only_fields = ('description', 'label')


class ProjectPropertySerializer(serializers.ModelSerializer):
    class Meta:
        model = ProjectProperty
        fields = '__all__'
        read_only_fields = ('description', 'label')


class CompanyTypeSerializer(serializers.ModelSerializer):
    class Meta:
        model = CompanyType
        fields = '__all__'
        read_only_fields = ('description', 'label')


class ProjectSerializer(serializers.ModelSerializer):
    class Meta:
        model = Project
        exclude = ['user', 'images']


class DetailedProjectSerializer(WritableNestedModelSerializer):
    scale = ProjectScaleSerializer(required=False)
    property = ProjectPropertySerializer(many=True, required=False)
    purpose = ProjectPurposeSerializer(many=True, required=False)
    fund_sources = FundSourcesSerializer(many=True, required=False)
    style = StyleSerializer(many=True, required=False)
    images = FileSerializers(required=False)

    class Meta:
        model = Project
        exclude = ['user']


class AddressListSerializer(WritableNestedModelSerializer):
    company_type = CompanyTypeSerializer(required=False)

    class Meta:
        model = AddressList
        exclude = ['project']
