import django_filters.rest_framework
from rest_framework import filters
from rest_framework import generics
from rest_framework.permissions import IsAuthenticated
from rest_framework.response import Response
from rest_framework.views import APIView

from DecisionPhase.models import Decision
from File.models import File
from ProjectInfoDisplay.models import \
    Project, Style, ProjectScale, FundSources, ProjectPurpose, ProjectProperty, CompanyType, AddressList
from utils.filter import ProjectFilter, AddressListFilter
from utils.page import StandardResultsSetPagination
from .serializers import ProjectSerializer, ProjectScaleSerializer, \
    ProjectPropertySerializer, ProjectPurposeSerializer, StyleSerializer, \
    FundSourcesSerializer, DetailedProjectSerializer, CompanyTypeSerializer, AddressListSerializer
from ImplementationPhase.models import DesignItem,DesignItemDoing

# from django.views.generic.base import View
# from django.shortcuts import HttpResponse
# from django.contrib.auth.mixins import LoginRequiredMixin
# import datetime
# import os
# from ConstructionConsultationSystem.settings import BASE_DIR
# import  uuid
# import time

class Scale(generics.ListCreateAPIView):
    queryset = ProjectScale.objects.all()
    serializer_class = ProjectScaleSerializer


class ProjectFundSources(generics.ListAPIView):
    queryset = FundSources.objects.all()
    serializer_class = FundSourcesSerializer


class ProjectStyle(generics.ListAPIView):
    queryset = Style.objects.all()
    serializer_class = StyleSerializer


class Purpose(generics.ListAPIView):
    queryset = ProjectPurpose.objects.all()
    serializer_class = ProjectPurposeSerializer


class Property(generics.ListAPIView):
    queryset = ProjectProperty.objects.all()
    serializer_class = ProjectPropertySerializer


class CompanyTypeAPI(generics.ListAPIView):
    queryset = CompanyType.objects.all()
    serializer_class = CompanyTypeSerializer


class ProjectInfo(generics.ListCreateAPIView):
    queryset = Project.objects.all()
    serializer_class = ProjectSerializer
    permissions = (IsAuthenticated,)
    pagination_class = StandardResultsSetPagination
    filter_backends = (django_filters.rest_framework.DjangoFilterBackend,
                       filters.SearchFilter,
                       filters.OrderingFilter)
    filterset_class = ProjectFilter
    ordering_fields = ('starting_date', 'finishing_date', 'investment')
    ordering = ('name',)
    search_fields = ('name', 'place')

    def get_queryset(self):
        user = self.request.user
        return self.queryset.filter(user=user)

    def perform_create(self, serializer):
        project = serializer.save()
        project.user.add(self.request.user)
        if self.request.data.get('uuid'):
            project.images = File.objects.get(uuid=self.request.data.get('uuid'))
        project.save()
        Decision.objects.create(project=project, title="项目建议")
        Decision.objects.create(project=project, title="环境评价")
        Decision.objects.create(project=project, title="风险评估")
        Decision.objects.create(project=project, title="可行性研究")
        Decision.objects.create(project=project, title="资金申请")
        Decision.objects.create(project=project, title="其他")

        design_item = \
            DesignItem.objects.create(project=project,name ="总规划")
        DesignItem.objects.create(project=project, name="合同")
        DesignItem.objects.create(project=project, name="概念性规划")
        DesignItem.objects.create(project=project, name="控制性规划")
        DesignItem.objects.create(project=project, name="规划")
        DesignItem.objects.create(project=project, name="方案")
        DesignItem.objects.create(project=project, name="勘察")
        DesignItem.objects.create(project=project, name="扩初")
        DesignItem.objects.create(project=project, name="施工图")
        DesignItem.objects.create(project=project, name="优化")
        DesignItem.objects.create(project=project, name="审查")
        DesignItem.objects.create(project=project, name="验收备案")
        DesignItem.objects.create(project=project, name="方案图")
        DesignItem.objects.create(project=project, name="设计变更")

        DesignItemDoing.objects.create(project=project,design_item=design_item)

class DetailedProjectInfo(generics.RetrieveUpdateDestroyAPIView):
    queryset = Project.objects.all()
    # serializer_class = DetailedProjectSerializer
    permissions = (IsAuthenticated,)
    lookup_field = 'id'

    def get_serializer_class(self):
        if (self.request.stream and self.request.stream.method == 'PUT'):
            return ProjectSerializer
        else:
            return DetailedProjectSerializer


class CheckIDAPIView(APIView):

    def post(self, request):
        data = request.data
        id = data.get('id')
        project = Project.objects.filter(id=id)
        if project:
            return Response('true')
        return Response('false')


class AddressListAPIView(generics.ListCreateAPIView):
    queryset = AddressList.objects.all()
    serializer_class = AddressListSerializer
    permissions = (IsAuthenticated,)
    pagination_class = StandardResultsSetPagination
    filter_backends = (django_filters.rest_framework.DjangoFilterBackend,
                       filters.SearchFilter,
                       filters.OrderingFilter)
    filterset_class = AddressListFilter
    ordering_fields = ('name', 'company')
    ordering = ('company',)
    search_fields = ('name', 'company', 'job')

    def get_queryset(self):
        return self.queryset.filter(project=self.request.GET.get('project_id'))

    def perform_create(self, serializer):
        serializer.save(project=Project.objects.get(id=self.request.GET.get('project_id')))


class AddressListDetailAPIView(generics.RetrieveUpdateDestroyAPIView):
    queryset = AddressList.objects.all()
    serializer_class = AddressListSerializer
    permissions = (IsAuthenticated,)
    lookup_field = 'id'
