from django.db import models
from django.contrib.auth.models import AbstractUser





class Actions(models.Model):
    name = models.CharField(max_length=100)
    description = models.CharField('description', max_length=100)

    class Meta:
        verbose_name = '具体操作'
        verbose_name_plural = 'actions'
        unique_together = (('name', 'description'),)

    def __str__(self):
        return self.name

class Permission(models.Model):

    name = models.CharField(max_length=100)
    description = models.CharField('description', max_length=100)
    actions = models.ManyToManyField(Actions,verbose_name='actions',blank=True)

    class Meta:
        verbose_name = '页面级权限'
        verbose_name_plural = 'permissions'
        unique_together = (('name', 'description'),)

    def __str__(self):
        return self.name

class Role(models.Model):
    name = models.CharField('name', max_length=80, unique=True)
    description = models.CharField('description', max_length=80)
    permissions = models.ManyToManyField(
        Permission,
        verbose_name='permissions',
        blank=True,
    )

    class Meta:
        verbose_name = '角色'
        verbose_name_plural = 'roles'

    def __str__(self):
        return self.name

    def natural_key(self):
        return (self.name,)

class User(AbstractUser):
    role = models.ForeignKey(Role,verbose_name='角色',related_name='user_role',
                                   on_delete=models.CASCADE,blank=True,null=True)
