from django.contrib.auth import authenticate, login, logout
from django.contrib.auth.models import User
from .serializers import UserInfoSerializer
from utils.api import MyAPIView
from rest_framework import exceptions
from rest_framework.response import Response
from rest_framework.views import APIView

class LoginAPIView(MyAPIView):
    def post(self, request):
        data = request.data
        user_name = data.get('username')
        pass_word = data.get('password')
        user = authenticate(request, username=user_name, password=pass_word)
        if user:
            login(request, user)
            return self.success('登陆成功')
        else:
            raise exceptions.ValidationError('用户不存在或者密码错误')


class LogoutAPIView(MyAPIView):
    """
    注销
    """
    def get(self, request):
        logout(request)
        return self.success('注销成功')


class UserInfoAPIView(APIView):
    def get(self, request):
        user = request.user
        serializer = UserInfoSerializer(user)
        return Response(serializer.data)


class ResetPasswordAPIView(MyAPIView):
    def post(self, request):
        user = request.user
        data = request.data
        username = user.username
        password_old = data.get('password-old')
        password_new = data.get('password')
        password_retry = data.get('password-retry')
        user = authenticate(username=username, password=password_old)
        if not user:
            raise exceptions.ValidationError('密码错误！')
        else:
            if password_new != password_retry:
                raise exceptions.ValidationError('两次输入的密码不一致！')
            else:
                user = User.objects.get(username=username)
                user.set_password(password_retry)
                user.save()
                return self.success(
                    '修改密码成功！'
                )
